@@ -10,5 +10,5 @@ This library is a bit of a grabbag of the following:
 * optimized implementations of common patterns
 """
 
-__title__ = 'snakeoil'
-__version__ = '0.10.3'
+__title__ = "snakeoil"
+__version__ = "0.10.5"
